      DOUBLE PRECISION FUNCTION NALPHAS(Q,AMZ,NLOOP)
c     Evaluation of strong coupling constant alpha_S
c     Author: R.K. Ellis

c     q -- scale at which alpha_s is to be evaluated
c     amz -- value of alpha_s at the mass of the Z-boson
c     nloop -- the number of loops (1,2, or 3) at which beta 
c     function is evaluated to determine running.
c     the values of the cmass and the bmass should be set
c     in common block qmass.

      IMPLICIT NONE
c--- added by JMC: use consistent value of MZ from common block
      DOUBLE PRECISION Q,T,AMZ,AMZ0,AMB,AMC,BMASS,CMASS,AS_OUT,ZMASS
      INTEGER NLOOP,NLOOP0,NF3,NF4,NF5
      PARAMETER(ZMASS=91.188D0)
      PARAMETER(CMASS=1.3D0)
      PARAMETER(BMASS=4.8D0)
      PARAMETER(NF5=5,NF4=4,NF3=3)
      SAVE AMZ0,NLOOP0,AMB,AMC
      DATA AMZ0,NLOOP0/0D0,0/

          

      IF (Q .LE. 0D0) THEN 
         WRITE(6,*) 'q .le. 0 in alphas'
         WRITE(6,*) 'q= ',Q
	 stop
c         PAUSE
      ENDIF
c--- 3-flavour running only
      if     (cmass .gt. 999d0) then
        T=2D0*DLOG(Q/ZMASS)
        CALL NEWTON1(T,AMZ,AS_OUT,NLOOP,NF3)
	NALPHAS=AS_OUT
	RETURN
c--- 4-flavour running only
      elseif (bmass .gt. 999d0) then
        T=2D0*DLOG(Q/ZMASS)
        CALL NEWTON1(T,AMZ,AS_OUT,NLOOP,NF4)
	NALPHAS=AS_OUT
	RETURN
      endif
c--- establish value of coupling at b- and c-mass and save
      IF ((AMZ .NE. AMZ0) .OR. (NLOOP .NE. NLOOP0)) THEN
         AMZ0=AMZ
         NLOOP0=NLOOP
         T=2D0*DLOG(BMASS/ZMASS)
         CALL NEWTON1(T,AMZ,AMB,NLOOP,NF5)
         T=2D0*DLOG(CMASS/BMASS)
         CALL NEWTON1(T,AMB,AMC,NLOOP,NF4)
      ENDIF
c--- evaluate strong coupling at scale q
      IF (Q  .LT. BMASS) THEN
           IF (Q  .LT. CMASS) THEN
             T=2D0*DLOG(Q/CMASS)
             CALL NEWTON1(T,AMC,AS_OUT,NLOOP,NF3)
           ELSE
             T=2D0*DLOG(Q/BMASS)
             CALL NEWTON1(T,AMB,AS_OUT,NLOOP,NF4)
           ENDIF
      ELSE
      T=2D0*DLOG(Q/ZMASS)
      CALL NEWTON1(T,AMZ,AS_OUT,NLOOP,NF5)
      ENDIF
      NALPHAS=AS_OUT
      RETURN
      END

